import { HttpResponse } from '@sap-cloud-sdk/http-client';
import { AzureOpenAiChatCompletionOutput, AzureOpenAiUsage } from './azure-openai-types.js';
/**
 * Azure OpenAI chat completion response.
 */
export declare class AzureOpenAiChatCompletionResponse {
    readonly rawResponse: HttpResponse;
    /**
     * The chat completion response.
     */
    readonly data: AzureOpenAiChatCompletionOutput;
    constructor(rawResponse: HttpResponse);
    /**
     * Usage of tokens in the response.
     * @returns Token usage.
     */
    getTokenUsage(): AzureOpenAiUsage;
    /**
     * Reason for stopping the completion.
     * @param choiceIndex - The index of the choice to parse.
     * @returns The finish reason.
     */
    getFinishReason(choiceIndex?: number): string | undefined;
    /**
     * Parses the Azure OpenAI response and returns the content.
     * @param choiceIndex - The index of the choice to parse.
     * @returns The message content.
     */
    getContent(choiceIndex?: number): string | undefined;
    private logInvalidChoiceIndex;
}
//# sourceMappingURL=azure-openai-chat-completion-response.d.ts.map