import { z } from 'zod';
/**
 * @internal
 */
export declare const azureOpenAiChatSystemMessageSchema: z.ZodObject<{
    role: z.ZodLiteral<"system">;
    name: z.ZodOptional<z.ZodString>;
    content: z.ZodString;
}, "strip", z.ZodTypeAny, {
    role: "system";
    content: string;
    name?: string | undefined;
}, {
    role: "system";
    content: string;
    name?: string | undefined;
}>;
/**
 * @internal
 */
export declare const azureOpenAiChatUserMessageSchema: z.ZodObject<{
    role: z.ZodLiteral<"user">;
    name: z.ZodOptional<z.ZodString>;
    content: z.ZodUnion<[z.ZodString, z.ZodArray<z.ZodUnion<[z.ZodObject<{
        type: z.ZodLiteral<"text">;
        text: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        text: string;
        type: "text";
    }, {
        text: string;
        type: "text";
    }>, z.ZodObject<{
        type: z.ZodLiteral<"image_url">;
        image_url: z.ZodUnion<[z.ZodString, z.ZodObject<{
            url: z.ZodString;
            detail: z.ZodDefault<z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"auto">, z.ZodLiteral<"low">, z.ZodLiteral<"high">]>>>;
        }, "strip", z.ZodTypeAny, {
            url: string;
            detail: "auto" | "low" | "high";
        }, {
            url: string;
            detail?: "auto" | "low" | "high" | undefined;
        }>]>;
    }, "strip", z.ZodTypeAny, {
        image_url: string | {
            url: string;
            detail: "auto" | "low" | "high";
        };
        type: "image_url";
    }, {
        image_url: string | {
            url: string;
            detail?: "auto" | "low" | "high" | undefined;
        };
        type: "image_url";
    }>]>, "many">]>;
}, "strip", z.ZodTypeAny, {
    role: "user";
    content: string | ({
        text: string;
        type: "text";
    } | {
        image_url: string | {
            url: string;
            detail: "auto" | "low" | "high";
        };
        type: "image_url";
    })[];
    name?: string | undefined;
}, {
    role: "user";
    content: string | ({
        text: string;
        type: "text";
    } | {
        image_url: string | {
            url: string;
            detail?: "auto" | "low" | "high" | undefined;
        };
        type: "image_url";
    })[];
    name?: string | undefined;
}>;
/**
 * @internal
 */
export declare const azureOpenAiChatFunctionCallSchema: z.ZodObject<{
    name: z.ZodString;
    arguments: z.ZodString;
}, "strip", z.ZodTypeAny, {
    name: string;
    arguments: string;
}, {
    name: string;
    arguments: string;
}>;
/**
 * @internal
 */
export declare const azureOpenAiChatToolCallSchema: z.ZodObject<{
    id: z.ZodString;
    type: z.ZodLiteral<"function">;
    function: z.ZodObject<{
        name: z.ZodString;
        arguments: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        name: string;
        arguments: string;
    }, {
        name: string;
        arguments: string;
    }>;
}, "strip", z.ZodTypeAny, {
    function: {
        name: string;
        arguments: string;
    };
    type: "function";
    id: string;
}, {
    function: {
        name: string;
        arguments: string;
    };
    type: "function";
    id: string;
}>;
/**
 * @internal
 */
export declare const azureOpenAiChatToolMessageSchema: z.ZodObject<{
    role: z.ZodLiteral<"tool">;
    content: z.ZodString;
    tool_call_id: z.ZodString;
}, "strip", z.ZodTypeAny, {
    role: "tool";
    content: string;
    tool_call_id: string;
}, {
    role: "tool";
    content: string;
    tool_call_id: string;
}>;
/**
 * @internal
 */
export declare const azureOpenAiChatFunctionMessageSchema: z.ZodObject<{
    role: z.ZodLiteral<"function">;
    content: z.ZodNullable<z.ZodString>;
    name: z.ZodString;
}, "strip", z.ZodTypeAny, {
    role: "function";
    name: string;
    content: string | null;
}, {
    role: "function";
    name: string;
    content: string | null;
}>;
/**
 * @internal
 */
export declare const azureOpenAiChatAssistantMessageSchema: z.ZodObject<{
    role: z.ZodLiteral<"assistant">;
    name: z.ZodOptional<z.ZodString>;
    content: z.ZodOptional<z.ZodString>;
    function_call: z.ZodOptional<z.ZodObject<{
        name: z.ZodString;
        arguments: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        name: string;
        arguments: string;
    }, {
        name: string;
        arguments: string;
    }>>;
    tool_calls: z.ZodOptional<z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        type: z.ZodLiteral<"function">;
        function: z.ZodObject<{
            name: z.ZodString;
            arguments: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            name: string;
            arguments: string;
        }, {
            name: string;
            arguments: string;
        }>;
    }, "strip", z.ZodTypeAny, {
        function: {
            name: string;
            arguments: string;
        };
        type: "function";
        id: string;
    }, {
        function: {
            name: string;
            arguments: string;
        };
        type: "function";
        id: string;
    }>, "many">>;
}, "strip", z.ZodTypeAny, {
    role: "assistant";
    name?: string | undefined;
    content?: string | undefined;
    function_call?: {
        name: string;
        arguments: string;
    } | undefined;
    tool_calls?: {
        function: {
            name: string;
            arguments: string;
        };
        type: "function";
        id: string;
    }[] | undefined;
}, {
    role: "assistant";
    name?: string | undefined;
    content?: string | undefined;
    function_call?: {
        name: string;
        arguments: string;
    } | undefined;
    tool_calls?: {
        function: {
            name: string;
            arguments: string;
        };
        type: "function";
        id: string;
    }[] | undefined;
}>;
/**
 * @internal
 */
export declare const azureOpenAiChatCompletionFunctionSchema: z.ZodObject<{
    name: z.ZodString;
    description: z.ZodOptional<z.ZodString>;
    parameters: z.ZodRecord<z.ZodString, z.ZodUnknown>;
}, "strip", z.ZodTypeAny, {
    name: string;
    parameters: Record<string, unknown>;
    description?: string | undefined;
}, {
    name: string;
    parameters: Record<string, unknown>;
    description?: string | undefined;
}>;
/**
 * @internal
 */
export declare const azureOpenAiChatCompletionToolSchema: z.ZodObject<{
    type: z.ZodLiteral<"function">;
    function: z.ZodObject<{
        name: z.ZodString;
        description: z.ZodOptional<z.ZodString>;
        parameters: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        parameters: Record<string, unknown>;
        description?: string | undefined;
    }, {
        name: string;
        parameters: Record<string, unknown>;
        description?: string | undefined;
    }>;
}, "strip", z.ZodTypeAny, {
    function: {
        name: string;
        parameters: Record<string, unknown>;
        description?: string | undefined;
    };
    type: "function";
}, {
    function: {
        name: string;
        parameters: Record<string, unknown>;
        description?: string | undefined;
    };
    type: "function";
}>;
/**
 * @internal
 */
export declare const azureOpenAiCompletionParametersSchema: z.ZodObject<{
    max_tokens: z.ZodOptional<z.ZodNumber>;
    temperature: z.ZodOptional<z.ZodNumber>;
    top_p: z.ZodOptional<z.ZodNumber>;
    logit_bias: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
    user: z.ZodOptional<z.ZodString>;
    n: z.ZodOptional<z.ZodNumber>;
    stop: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodArray<z.ZodString, "many">]>>;
    presence_penalty: z.ZodOptional<z.ZodNumber>;
    frequency_penalty: z.ZodOptional<z.ZodNumber>;
}, "strip", z.ZodTypeAny, {
    user?: string | undefined;
    max_tokens?: number | undefined;
    temperature?: number | undefined;
    top_p?: number | undefined;
    logit_bias?: Record<string, unknown> | undefined;
    n?: number | undefined;
    stop?: string | string[] | undefined;
    presence_penalty?: number | undefined;
    frequency_penalty?: number | undefined;
}, {
    user?: string | undefined;
    max_tokens?: number | undefined;
    temperature?: number | undefined;
    top_p?: number | undefined;
    logit_bias?: Record<string, unknown> | undefined;
    n?: number | undefined;
    stop?: string | string[] | undefined;
    presence_penalty?: number | undefined;
    frequency_penalty?: number | undefined;
}>;
/**
 * @internal
 */
export declare const azureOpenAiChatMessageSchema: z.ZodUnion<[z.ZodObject<{
    role: z.ZodLiteral<"system">;
    name: z.ZodOptional<z.ZodString>;
    content: z.ZodString;
}, "strip", z.ZodTypeAny, {
    role: "system";
    content: string;
    name?: string | undefined;
}, {
    role: "system";
    content: string;
    name?: string | undefined;
}>, z.ZodObject<{
    role: z.ZodLiteral<"user">;
    name: z.ZodOptional<z.ZodString>;
    content: z.ZodUnion<[z.ZodString, z.ZodArray<z.ZodUnion<[z.ZodObject<{
        type: z.ZodLiteral<"text">;
        text: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        text: string;
        type: "text";
    }, {
        text: string;
        type: "text";
    }>, z.ZodObject<{
        type: z.ZodLiteral<"image_url">;
        image_url: z.ZodUnion<[z.ZodString, z.ZodObject<{
            url: z.ZodString;
            detail: z.ZodDefault<z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"auto">, z.ZodLiteral<"low">, z.ZodLiteral<"high">]>>>;
        }, "strip", z.ZodTypeAny, {
            url: string;
            detail: "auto" | "low" | "high";
        }, {
            url: string;
            detail?: "auto" | "low" | "high" | undefined;
        }>]>;
    }, "strip", z.ZodTypeAny, {
        image_url: string | {
            url: string;
            detail: "auto" | "low" | "high";
        };
        type: "image_url";
    }, {
        image_url: string | {
            url: string;
            detail?: "auto" | "low" | "high" | undefined;
        };
        type: "image_url";
    }>]>, "many">]>;
}, "strip", z.ZodTypeAny, {
    role: "user";
    content: string | ({
        text: string;
        type: "text";
    } | {
        image_url: string | {
            url: string;
            detail: "auto" | "low" | "high";
        };
        type: "image_url";
    })[];
    name?: string | undefined;
}, {
    role: "user";
    content: string | ({
        text: string;
        type: "text";
    } | {
        image_url: string | {
            url: string;
            detail?: "auto" | "low" | "high" | undefined;
        };
        type: "image_url";
    })[];
    name?: string | undefined;
}>, z.ZodObject<{
    role: z.ZodLiteral<"assistant">;
    name: z.ZodOptional<z.ZodString>;
    content: z.ZodOptional<z.ZodString>;
    function_call: z.ZodOptional<z.ZodObject<{
        name: z.ZodString;
        arguments: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        name: string;
        arguments: string;
    }, {
        name: string;
        arguments: string;
    }>>;
    tool_calls: z.ZodOptional<z.ZodArray<z.ZodObject<{
        id: z.ZodString;
        type: z.ZodLiteral<"function">;
        function: z.ZodObject<{
            name: z.ZodString;
            arguments: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            name: string;
            arguments: string;
        }, {
            name: string;
            arguments: string;
        }>;
    }, "strip", z.ZodTypeAny, {
        function: {
            name: string;
            arguments: string;
        };
        type: "function";
        id: string;
    }, {
        function: {
            name: string;
            arguments: string;
        };
        type: "function";
        id: string;
    }>, "many">>;
}, "strip", z.ZodTypeAny, {
    role: "assistant";
    name?: string | undefined;
    content?: string | undefined;
    function_call?: {
        name: string;
        arguments: string;
    } | undefined;
    tool_calls?: {
        function: {
            name: string;
            arguments: string;
        };
        type: "function";
        id: string;
    }[] | undefined;
}, {
    role: "assistant";
    name?: string | undefined;
    content?: string | undefined;
    function_call?: {
        name: string;
        arguments: string;
    } | undefined;
    tool_calls?: {
        function: {
            name: string;
            arguments: string;
        };
        type: "function";
        id: string;
    }[] | undefined;
}>, z.ZodObject<{
    role: z.ZodLiteral<"tool">;
    content: z.ZodString;
    tool_call_id: z.ZodString;
}, "strip", z.ZodTypeAny, {
    role: "tool";
    content: string;
    tool_call_id: string;
}, {
    role: "tool";
    content: string;
    tool_call_id: string;
}>, z.ZodObject<{
    role: z.ZodLiteral<"function">;
    content: z.ZodNullable<z.ZodString>;
    name: z.ZodString;
}, "strip", z.ZodTypeAny, {
    role: "function";
    name: string;
    content: string | null;
}, {
    role: "function";
    name: string;
    content: string | null;
}>]>;
/**
 * @internal
 */
export declare const azureOpenAiEmbeddingParametersSchema: z.ZodObject<{
    input: z.ZodUnion<[z.ZodArray<z.ZodString, "many">, z.ZodString]>;
    user: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    input: string | string[];
    user?: string | undefined;
}, {
    input: string | string[];
    user?: string | undefined;
}>;
/**
 * @internal
 */
export declare const azureOpenAiUsageSchema: z.ZodObject<{
    completion_tokens: z.ZodNumber;
    prompt_tokens: z.ZodNumber;
    total_tokens: z.ZodNumber;
}, "strip", z.ZodTypeAny, {
    completion_tokens: number;
    prompt_tokens: number;
    total_tokens: number;
}, {
    completion_tokens: number;
    prompt_tokens: number;
    total_tokens: number;
}>;
/**
 * @internal
 */
export declare const azureOpenAiErrorBaseSchema: z.ZodObject<{
    code: z.ZodOptional<z.ZodString>;
    message: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    code?: string | undefined;
    message?: string | undefined;
}, {
    code?: string | undefined;
    message?: string | undefined;
}>;
/**
 * @internal
 */
export declare const azureOpenAiContentFilterResultBaseSchema: z.ZodObject<{
    filtered: z.ZodBoolean;
}, "strip", z.ZodTypeAny, {
    filtered: boolean;
}, {
    filtered: boolean;
}>;
/**
 * @internal
 */
export declare const azureOpenAiContentFilterDetectedResultSchema: z.ZodObject<z.objectUtil.extendShape<{
    filtered: z.ZodBoolean;
}, {
    detected: z.ZodBoolean;
}>, "strip", z.ZodTypeAny, {
    filtered: boolean;
    detected: boolean;
}, {
    filtered: boolean;
    detected: boolean;
}>;
/**
 * @internal
 */
export declare const azureOpenAiContentFilterSeverityResultSchema: z.ZodObject<z.objectUtil.extendShape<{
    filtered: z.ZodBoolean;
}, {
    severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
}>, "strip", z.ZodTypeAny, {
    filtered: boolean;
    severity: "low" | "high" | "safe" | "medium";
}, {
    filtered: boolean;
    severity: "low" | "high" | "safe" | "medium";
}>;
/**
 * @internal
 */
export declare const azureOpenAiEmbeddingOutputSchema: z.ZodObject<{
    object: z.ZodLiteral<"list">;
    model: z.ZodString;
    data: z.ZodTuple<[z.ZodObject<{
        object: z.ZodLiteral<"embedding">;
        embedding: z.ZodArray<z.ZodNumber, "many">;
        index: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        object: "embedding";
        embedding: number[];
        index: number;
    }, {
        object: "embedding";
        embedding: number[];
        index: number;
    }>], null>;
    usage: z.ZodObject<{
        prompt_tokens: z.ZodNumber;
        total_tokens: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        prompt_tokens: number;
        total_tokens: number;
    }, {
        prompt_tokens: number;
        total_tokens: number;
    }>;
}, "strip", z.ZodTypeAny, {
    object: "list";
    model: string;
    data: [{
        object: "embedding";
        embedding: number[];
        index: number;
    }];
    usage: {
        prompt_tokens: number;
        total_tokens: number;
    };
}, {
    object: "list";
    model: string;
    data: [{
        object: "embedding";
        embedding: number[];
        index: number;
    }];
    usage: {
        prompt_tokens: number;
        total_tokens: number;
    };
}>;
/**
 * @internal
 */
export declare const azureOpenAiChatCompletionParametersSchema: z.ZodObject<z.objectUtil.extendShape<{
    max_tokens: z.ZodOptional<z.ZodNumber>;
    temperature: z.ZodOptional<z.ZodNumber>;
    top_p: z.ZodOptional<z.ZodNumber>;
    logit_bias: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
    user: z.ZodOptional<z.ZodString>;
    n: z.ZodOptional<z.ZodNumber>;
    stop: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodArray<z.ZodString, "many">]>>;
    presence_penalty: z.ZodOptional<z.ZodNumber>;
    frequency_penalty: z.ZodOptional<z.ZodNumber>;
}, {
    messages: z.ZodArray<z.ZodUnion<[z.ZodObject<{
        role: z.ZodLiteral<"system">;
        name: z.ZodOptional<z.ZodString>;
        content: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        role: "system";
        content: string;
        name?: string | undefined;
    }, {
        role: "system";
        content: string;
        name?: string | undefined;
    }>, z.ZodObject<{
        role: z.ZodLiteral<"user">;
        name: z.ZodOptional<z.ZodString>;
        content: z.ZodUnion<[z.ZodString, z.ZodArray<z.ZodUnion<[z.ZodObject<{
            type: z.ZodLiteral<"text">;
            text: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            text: string;
            type: "text";
        }, {
            text: string;
            type: "text";
        }>, z.ZodObject<{
            type: z.ZodLiteral<"image_url">;
            image_url: z.ZodUnion<[z.ZodString, z.ZodObject<{
                url: z.ZodString;
                detail: z.ZodDefault<z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"auto">, z.ZodLiteral<"low">, z.ZodLiteral<"high">]>>>;
            }, "strip", z.ZodTypeAny, {
                url: string;
                detail: "auto" | "low" | "high";
            }, {
                url: string;
                detail?: "auto" | "low" | "high" | undefined;
            }>]>;
        }, "strip", z.ZodTypeAny, {
            image_url: string | {
                url: string;
                detail: "auto" | "low" | "high";
            };
            type: "image_url";
        }, {
            image_url: string | {
                url: string;
                detail?: "auto" | "low" | "high" | undefined;
            };
            type: "image_url";
        }>]>, "many">]>;
    }, "strip", z.ZodTypeAny, {
        role: "user";
        content: string | ({
            text: string;
            type: "text";
        } | {
            image_url: string | {
                url: string;
                detail: "auto" | "low" | "high";
            };
            type: "image_url";
        })[];
        name?: string | undefined;
    }, {
        role: "user";
        content: string | ({
            text: string;
            type: "text";
        } | {
            image_url: string | {
                url: string;
                detail?: "auto" | "low" | "high" | undefined;
            };
            type: "image_url";
        })[];
        name?: string | undefined;
    }>, z.ZodObject<{
        role: z.ZodLiteral<"assistant">;
        name: z.ZodOptional<z.ZodString>;
        content: z.ZodOptional<z.ZodString>;
        function_call: z.ZodOptional<z.ZodObject<{
            name: z.ZodString;
            arguments: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            name: string;
            arguments: string;
        }, {
            name: string;
            arguments: string;
        }>>;
        tool_calls: z.ZodOptional<z.ZodArray<z.ZodObject<{
            id: z.ZodString;
            type: z.ZodLiteral<"function">;
            function: z.ZodObject<{
                name: z.ZodString;
                arguments: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                name: string;
                arguments: string;
            }, {
                name: string;
                arguments: string;
            }>;
        }, "strip", z.ZodTypeAny, {
            function: {
                name: string;
                arguments: string;
            };
            type: "function";
            id: string;
        }, {
            function: {
                name: string;
                arguments: string;
            };
            type: "function";
            id: string;
        }>, "many">>;
    }, "strip", z.ZodTypeAny, {
        role: "assistant";
        name?: string | undefined;
        content?: string | undefined;
        function_call?: {
            name: string;
            arguments: string;
        } | undefined;
        tool_calls?: {
            function: {
                name: string;
                arguments: string;
            };
            type: "function";
            id: string;
        }[] | undefined;
    }, {
        role: "assistant";
        name?: string | undefined;
        content?: string | undefined;
        function_call?: {
            name: string;
            arguments: string;
        } | undefined;
        tool_calls?: {
            function: {
                name: string;
                arguments: string;
            };
            type: "function";
            id: string;
        }[] | undefined;
    }>, z.ZodObject<{
        role: z.ZodLiteral<"tool">;
        content: z.ZodString;
        tool_call_id: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        role: "tool";
        content: string;
        tool_call_id: string;
    }, {
        role: "tool";
        content: string;
        tool_call_id: string;
    }>, z.ZodObject<{
        role: z.ZodLiteral<"function">;
        content: z.ZodNullable<z.ZodString>;
        name: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        role: "function";
        name: string;
        content: string | null;
    }, {
        role: "function";
        name: string;
        content: string | null;
    }>]>, "many">;
    response_format: z.ZodOptional<z.ZodObject<{
        type: z.ZodDefault<z.ZodUnion<[z.ZodLiteral<"text">, z.ZodLiteral<"json_object">]>>;
    }, "strip", z.ZodTypeAny, {
        type: "text" | "json_object";
    }, {
        type?: "text" | "json_object" | undefined;
    }>>;
    seed: z.ZodOptional<z.ZodNumber>;
    functions: z.ZodOptional<z.ZodArray<z.ZodObject<{
        name: z.ZodString;
        description: z.ZodOptional<z.ZodString>;
        parameters: z.ZodRecord<z.ZodString, z.ZodUnknown>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        parameters: Record<string, unknown>;
        description?: string | undefined;
    }, {
        name: string;
        parameters: Record<string, unknown>;
        description?: string | undefined;
    }>, "many">>;
    tools: z.ZodOptional<z.ZodArray<z.ZodObject<{
        type: z.ZodLiteral<"function">;
        function: z.ZodObject<{
            name: z.ZodString;
            description: z.ZodOptional<z.ZodString>;
            parameters: z.ZodRecord<z.ZodString, z.ZodUnknown>;
        }, "strip", z.ZodTypeAny, {
            name: string;
            parameters: Record<string, unknown>;
            description?: string | undefined;
        }, {
            name: string;
            parameters: Record<string, unknown>;
            description?: string | undefined;
        }>;
    }, "strip", z.ZodTypeAny, {
        function: {
            name: string;
            parameters: Record<string, unknown>;
            description?: string | undefined;
        };
        type: "function";
    }, {
        function: {
            name: string;
            parameters: Record<string, unknown>;
            description?: string | undefined;
        };
        type: "function";
    }>, "many">>;
    tool_choice: z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"none">, z.ZodLiteral<"auto">, z.ZodObject<{
        type: z.ZodLiteral<"function">;
        function: z.ZodObject<{
            name: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            name: string;
        }, {
            name: string;
        }>;
    }, "strip", z.ZodTypeAny, {
        function: {
            name: string;
        };
        type: "function";
    }, {
        function: {
            name: string;
        };
        type: "function";
    }>]>>;
}>, "strip", z.ZodTypeAny, {
    messages: ({
        role: "system";
        content: string;
        name?: string | undefined;
    } | {
        role: "user";
        content: string | ({
            text: string;
            type: "text";
        } | {
            image_url: string | {
                url: string;
                detail: "auto" | "low" | "high";
            };
            type: "image_url";
        })[];
        name?: string | undefined;
    } | {
        role: "tool";
        content: string;
        tool_call_id: string;
    } | {
        role: "function";
        name: string;
        content: string | null;
    } | {
        role: "assistant";
        name?: string | undefined;
        content?: string | undefined;
        function_call?: {
            name: string;
            arguments: string;
        } | undefined;
        tool_calls?: {
            function: {
                name: string;
                arguments: string;
            };
            type: "function";
            id: string;
        }[] | undefined;
    })[];
    user?: string | undefined;
    response_format?: {
        type: "text" | "json_object";
    } | undefined;
    seed?: number | undefined;
    functions?: {
        name: string;
        parameters: Record<string, unknown>;
        description?: string | undefined;
    }[] | undefined;
    tools?: {
        function: {
            name: string;
            parameters: Record<string, unknown>;
            description?: string | undefined;
        };
        type: "function";
    }[] | undefined;
    tool_choice?: "auto" | "none" | {
        function: {
            name: string;
        };
        type: "function";
    } | undefined;
    max_tokens?: number | undefined;
    temperature?: number | undefined;
    top_p?: number | undefined;
    logit_bias?: Record<string, unknown> | undefined;
    n?: number | undefined;
    stop?: string | string[] | undefined;
    presence_penalty?: number | undefined;
    frequency_penalty?: number | undefined;
}, {
    messages: ({
        role: "system";
        content: string;
        name?: string | undefined;
    } | {
        role: "user";
        content: string | ({
            text: string;
            type: "text";
        } | {
            image_url: string | {
                url: string;
                detail?: "auto" | "low" | "high" | undefined;
            };
            type: "image_url";
        })[];
        name?: string | undefined;
    } | {
        role: "tool";
        content: string;
        tool_call_id: string;
    } | {
        role: "function";
        name: string;
        content: string | null;
    } | {
        role: "assistant";
        name?: string | undefined;
        content?: string | undefined;
        function_call?: {
            name: string;
            arguments: string;
        } | undefined;
        tool_calls?: {
            function: {
                name: string;
                arguments: string;
            };
            type: "function";
            id: string;
        }[] | undefined;
    })[];
    user?: string | undefined;
    response_format?: {
        type?: "text" | "json_object" | undefined;
    } | undefined;
    seed?: number | undefined;
    functions?: {
        name: string;
        parameters: Record<string, unknown>;
        description?: string | undefined;
    }[] | undefined;
    tools?: {
        function: {
            name: string;
            parameters: Record<string, unknown>;
            description?: string | undefined;
        };
        type: "function";
    }[] | undefined;
    tool_choice?: "auto" | "none" | {
        function: {
            name: string;
        };
        type: "function";
    } | undefined;
    max_tokens?: number | undefined;
    temperature?: number | undefined;
    top_p?: number | undefined;
    logit_bias?: Record<string, unknown> | undefined;
    n?: number | undefined;
    stop?: string | string[] | undefined;
    presence_penalty?: number | undefined;
    frequency_penalty?: number | undefined;
}>;
/**
 * @internal
 */
export declare const azureOpenAiContentFilterResultsBaseSchema: z.ZodObject<{
    sexual: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
        filtered: z.ZodBoolean;
    }, {
        severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
    }>, "strip", z.ZodTypeAny, {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    }, {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    }>>;
    violence: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
        filtered: z.ZodBoolean;
    }, {
        severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
    }>, "strip", z.ZodTypeAny, {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    }, {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    }>>;
    hate: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
        filtered: z.ZodBoolean;
    }, {
        severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
    }>, "strip", z.ZodTypeAny, {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    }, {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    }>>;
    self_harm: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
        filtered: z.ZodBoolean;
    }, {
        severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
    }>, "strip", z.ZodTypeAny, {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    }, {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    }>>;
    profanity: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
        filtered: z.ZodBoolean;
    }, {
        detected: z.ZodBoolean;
    }>, "strip", z.ZodTypeAny, {
        filtered: boolean;
        detected: boolean;
    }, {
        filtered: boolean;
        detected: boolean;
    }>>;
    error: z.ZodOptional<z.ZodObject<{
        code: z.ZodOptional<z.ZodString>;
        message: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        code?: string | undefined;
        message?: string | undefined;
    }, {
        code?: string | undefined;
        message?: string | undefined;
    }>>;
}, "strip", z.ZodTypeAny, {
    sexual?: {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    } | undefined;
    violence?: {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    } | undefined;
    hate?: {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    } | undefined;
    self_harm?: {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    } | undefined;
    profanity?: {
        filtered: boolean;
        detected: boolean;
    } | undefined;
    error?: {
        code?: string | undefined;
        message?: string | undefined;
    } | undefined;
}, {
    sexual?: {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    } | undefined;
    violence?: {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    } | undefined;
    hate?: {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    } | undefined;
    self_harm?: {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    } | undefined;
    profanity?: {
        filtered: boolean;
        detected: boolean;
    } | undefined;
    error?: {
        code?: string | undefined;
        message?: string | undefined;
    } | undefined;
}>;
/**
 * @internal
 */
export declare const azureOpenAiContentFilterPromptResultsSchema: z.ZodObject<z.objectUtil.extendShape<{
    sexual: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
        filtered: z.ZodBoolean;
    }, {
        severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
    }>, "strip", z.ZodTypeAny, {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    }, {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    }>>;
    violence: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
        filtered: z.ZodBoolean;
    }, {
        severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
    }>, "strip", z.ZodTypeAny, {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    }, {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    }>>;
    hate: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
        filtered: z.ZodBoolean;
    }, {
        severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
    }>, "strip", z.ZodTypeAny, {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    }, {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    }>>;
    self_harm: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
        filtered: z.ZodBoolean;
    }, {
        severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
    }>, "strip", z.ZodTypeAny, {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    }, {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    }>>;
    profanity: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
        filtered: z.ZodBoolean;
    }, {
        detected: z.ZodBoolean;
    }>, "strip", z.ZodTypeAny, {
        filtered: boolean;
        detected: boolean;
    }, {
        filtered: boolean;
        detected: boolean;
    }>>;
    error: z.ZodOptional<z.ZodObject<{
        code: z.ZodOptional<z.ZodString>;
        message: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        code?: string | undefined;
        message?: string | undefined;
    }, {
        code?: string | undefined;
        message?: string | undefined;
    }>>;
}, {
    jailbreak: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
        filtered: z.ZodBoolean;
    }, {
        detected: z.ZodBoolean;
    }>, "strip", z.ZodTypeAny, {
        filtered: boolean;
        detected: boolean;
    }, {
        filtered: boolean;
        detected: boolean;
    }>>;
}>, "strip", z.ZodTypeAny, {
    jailbreak?: {
        filtered: boolean;
        detected: boolean;
    } | undefined;
    sexual?: {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    } | undefined;
    violence?: {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    } | undefined;
    hate?: {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    } | undefined;
    self_harm?: {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    } | undefined;
    profanity?: {
        filtered: boolean;
        detected: boolean;
    } | undefined;
    error?: {
        code?: string | undefined;
        message?: string | undefined;
    } | undefined;
}, {
    jailbreak?: {
        filtered: boolean;
        detected: boolean;
    } | undefined;
    sexual?: {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    } | undefined;
    violence?: {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    } | undefined;
    hate?: {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    } | undefined;
    self_harm?: {
        filtered: boolean;
        severity: "low" | "high" | "safe" | "medium";
    } | undefined;
    profanity?: {
        filtered: boolean;
        detected: boolean;
    } | undefined;
    error?: {
        code?: string | undefined;
        message?: string | undefined;
    } | undefined;
}>;
/**
 * @internal
 */
export declare const azureOpenAiPromptFilterResultSchema: z.ZodObject<{
    prompt_index: z.ZodOptional<z.ZodNumber>;
    content_filter_results: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
        sexual: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
            filtered: z.ZodBoolean;
        }, {
            severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
        }>, "strip", z.ZodTypeAny, {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        }, {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        }>>;
        violence: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
            filtered: z.ZodBoolean;
        }, {
            severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
        }>, "strip", z.ZodTypeAny, {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        }, {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        }>>;
        hate: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
            filtered: z.ZodBoolean;
        }, {
            severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
        }>, "strip", z.ZodTypeAny, {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        }, {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        }>>;
        self_harm: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
            filtered: z.ZodBoolean;
        }, {
            severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
        }>, "strip", z.ZodTypeAny, {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        }, {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        }>>;
        profanity: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
            filtered: z.ZodBoolean;
        }, {
            detected: z.ZodBoolean;
        }>, "strip", z.ZodTypeAny, {
            filtered: boolean;
            detected: boolean;
        }, {
            filtered: boolean;
            detected: boolean;
        }>>;
        error: z.ZodOptional<z.ZodObject<{
            code: z.ZodOptional<z.ZodString>;
            message: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            code?: string | undefined;
            message?: string | undefined;
        }, {
            code?: string | undefined;
            message?: string | undefined;
        }>>;
    }, {
        jailbreak: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
            filtered: z.ZodBoolean;
        }, {
            detected: z.ZodBoolean;
        }>, "strip", z.ZodTypeAny, {
            filtered: boolean;
            detected: boolean;
        }, {
            filtered: boolean;
            detected: boolean;
        }>>;
    }>, "strip", z.ZodTypeAny, {
        jailbreak?: {
            filtered: boolean;
            detected: boolean;
        } | undefined;
        sexual?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        violence?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        hate?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        self_harm?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        profanity?: {
            filtered: boolean;
            detected: boolean;
        } | undefined;
        error?: {
            code?: string | undefined;
            message?: string | undefined;
        } | undefined;
    }, {
        jailbreak?: {
            filtered: boolean;
            detected: boolean;
        } | undefined;
        sexual?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        violence?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        hate?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        self_harm?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        profanity?: {
            filtered: boolean;
            detected: boolean;
        } | undefined;
        error?: {
            code?: string | undefined;
            message?: string | undefined;
        } | undefined;
    }>>;
}, "strip", z.ZodTypeAny, {
    prompt_index?: number | undefined;
    content_filter_results?: {
        jailbreak?: {
            filtered: boolean;
            detected: boolean;
        } | undefined;
        sexual?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        violence?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        hate?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        self_harm?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        profanity?: {
            filtered: boolean;
            detected: boolean;
        } | undefined;
        error?: {
            code?: string | undefined;
            message?: string | undefined;
        } | undefined;
    } | undefined;
}, {
    prompt_index?: number | undefined;
    content_filter_results?: {
        jailbreak?: {
            filtered: boolean;
            detected: boolean;
        } | undefined;
        sexual?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        violence?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        hate?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        self_harm?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        profanity?: {
            filtered: boolean;
            detected: boolean;
        } | undefined;
        error?: {
            code?: string | undefined;
            message?: string | undefined;
        } | undefined;
    } | undefined;
}>;
/**
 * @internal
 */
export declare const azureOpenAiCompletionOutputSchema: z.ZodObject<{
    created: z.ZodNumber;
    id: z.ZodString;
    model: z.ZodString;
    object: z.ZodUnion<[z.ZodLiteral<"chat.completion">, z.ZodLiteral<"text_completion">]>;
    usage: z.ZodObject<{
        completion_tokens: z.ZodNumber;
        prompt_tokens: z.ZodNumber;
        total_tokens: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        completion_tokens: number;
        prompt_tokens: number;
        total_tokens: number;
    }, {
        completion_tokens: number;
        prompt_tokens: number;
        total_tokens: number;
    }>;
    prompt_filter_results: z.ZodOptional<z.ZodArray<z.ZodObject<{
        prompt_index: z.ZodOptional<z.ZodNumber>;
        content_filter_results: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
            sexual: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                filtered: z.ZodBoolean;
            }, {
                severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
            }>, "strip", z.ZodTypeAny, {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            }, {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            }>>;
            violence: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                filtered: z.ZodBoolean;
            }, {
                severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
            }>, "strip", z.ZodTypeAny, {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            }, {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            }>>;
            hate: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                filtered: z.ZodBoolean;
            }, {
                severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
            }>, "strip", z.ZodTypeAny, {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            }, {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            }>>;
            self_harm: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                filtered: z.ZodBoolean;
            }, {
                severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
            }>, "strip", z.ZodTypeAny, {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            }, {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            }>>;
            profanity: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                filtered: z.ZodBoolean;
            }, {
                detected: z.ZodBoolean;
            }>, "strip", z.ZodTypeAny, {
                filtered: boolean;
                detected: boolean;
            }, {
                filtered: boolean;
                detected: boolean;
            }>>;
            error: z.ZodOptional<z.ZodObject<{
                code: z.ZodOptional<z.ZodString>;
                message: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                code?: string | undefined;
                message?: string | undefined;
            }, {
                code?: string | undefined;
                message?: string | undefined;
            }>>;
        }, {
            jailbreak: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                filtered: z.ZodBoolean;
            }, {
                detected: z.ZodBoolean;
            }>, "strip", z.ZodTypeAny, {
                filtered: boolean;
                detected: boolean;
            }, {
                filtered: boolean;
                detected: boolean;
            }>>;
        }>, "strip", z.ZodTypeAny, {
            jailbreak?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            sexual?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            violence?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            hate?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            self_harm?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            profanity?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            error?: {
                code?: string | undefined;
                message?: string | undefined;
            } | undefined;
        }, {
            jailbreak?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            sexual?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            violence?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            hate?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            self_harm?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            profanity?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            error?: {
                code?: string | undefined;
                message?: string | undefined;
            } | undefined;
        }>>;
    }, "strip", z.ZodTypeAny, {
        prompt_index?: number | undefined;
        content_filter_results?: {
            jailbreak?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            sexual?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            violence?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            hate?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            self_harm?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            profanity?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            error?: {
                code?: string | undefined;
                message?: string | undefined;
            } | undefined;
        } | undefined;
    }, {
        prompt_index?: number | undefined;
        content_filter_results?: {
            jailbreak?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            sexual?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            violence?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            hate?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            self_harm?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            profanity?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            error?: {
                code?: string | undefined;
                message?: string | undefined;
            } | undefined;
        } | undefined;
    }>, "many">>;
}, "strip", z.ZodTypeAny, {
    object: "chat.completion" | "text_completion";
    id: string;
    model: string;
    usage: {
        completion_tokens: number;
        prompt_tokens: number;
        total_tokens: number;
    };
    created: number;
    prompt_filter_results?: {
        prompt_index?: number | undefined;
        content_filter_results?: {
            jailbreak?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            sexual?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            violence?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            hate?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            self_harm?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            profanity?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            error?: {
                code?: string | undefined;
                message?: string | undefined;
            } | undefined;
        } | undefined;
    }[] | undefined;
}, {
    object: "chat.completion" | "text_completion";
    id: string;
    model: string;
    usage: {
        completion_tokens: number;
        prompt_tokens: number;
        total_tokens: number;
    };
    created: number;
    prompt_filter_results?: {
        prompt_index?: number | undefined;
        content_filter_results?: {
            jailbreak?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            sexual?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            violence?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            hate?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            self_harm?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            profanity?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            error?: {
                code?: string | undefined;
                message?: string | undefined;
            } | undefined;
        } | undefined;
    }[] | undefined;
}>;
/**
 * @internal
 */
export declare const azureOpenAiCompletionChoiceSchema: z.ZodObject<{
    finish_reason: z.ZodOptional<z.ZodString>;
    index: z.ZodNumber;
    content_filter_results: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
        sexual: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
            filtered: z.ZodBoolean;
        }, {
            severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
        }>, "strip", z.ZodTypeAny, {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        }, {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        }>>;
        violence: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
            filtered: z.ZodBoolean;
        }, {
            severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
        }>, "strip", z.ZodTypeAny, {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        }, {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        }>>;
        hate: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
            filtered: z.ZodBoolean;
        }, {
            severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
        }>, "strip", z.ZodTypeAny, {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        }, {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        }>>;
        self_harm: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
            filtered: z.ZodBoolean;
        }, {
            severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
        }>, "strip", z.ZodTypeAny, {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        }, {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        }>>;
        profanity: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
            filtered: z.ZodBoolean;
        }, {
            detected: z.ZodBoolean;
        }>, "strip", z.ZodTypeAny, {
            filtered: boolean;
            detected: boolean;
        }, {
            filtered: boolean;
            detected: boolean;
        }>>;
        error: z.ZodOptional<z.ZodObject<{
            code: z.ZodOptional<z.ZodString>;
            message: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            code?: string | undefined;
            message?: string | undefined;
        }, {
            code?: string | undefined;
            message?: string | undefined;
        }>>;
    }, {
        jailbreak: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
            filtered: z.ZodBoolean;
        }, {
            detected: z.ZodBoolean;
        }>, "strip", z.ZodTypeAny, {
            filtered: boolean;
            detected: boolean;
        }, {
            filtered: boolean;
            detected: boolean;
        }>>;
    }>, "strip", z.ZodTypeAny, {
        jailbreak?: {
            filtered: boolean;
            detected: boolean;
        } | undefined;
        sexual?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        violence?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        hate?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        self_harm?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        profanity?: {
            filtered: boolean;
            detected: boolean;
        } | undefined;
        error?: {
            code?: string | undefined;
            message?: string | undefined;
        } | undefined;
    }, {
        jailbreak?: {
            filtered: boolean;
            detected: boolean;
        } | undefined;
        sexual?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        violence?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        hate?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        self_harm?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        profanity?: {
            filtered: boolean;
            detected: boolean;
        } | undefined;
        error?: {
            code?: string | undefined;
            message?: string | undefined;
        } | undefined;
    }>>;
}, "strip", z.ZodTypeAny, {
    index: number;
    content_filter_results?: {
        jailbreak?: {
            filtered: boolean;
            detected: boolean;
        } | undefined;
        sexual?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        violence?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        hate?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        self_harm?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        profanity?: {
            filtered: boolean;
            detected: boolean;
        } | undefined;
        error?: {
            code?: string | undefined;
            message?: string | undefined;
        } | undefined;
    } | undefined;
    finish_reason?: string | undefined;
}, {
    index: number;
    content_filter_results?: {
        jailbreak?: {
            filtered: boolean;
            detected: boolean;
        } | undefined;
        sexual?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        violence?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        hate?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        self_harm?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        profanity?: {
            filtered: boolean;
            detected: boolean;
        } | undefined;
        error?: {
            code?: string | undefined;
            message?: string | undefined;
        } | undefined;
    } | undefined;
    finish_reason?: string | undefined;
}>;
/**
 * @internal
 */
export declare const azureOpenAiChatCompletionChoiceSchema: z.ZodObject<z.objectUtil.extendShape<{
    finish_reason: z.ZodOptional<z.ZodString>;
    index: z.ZodNumber;
    content_filter_results: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
        sexual: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
            filtered: z.ZodBoolean;
        }, {
            severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
        }>, "strip", z.ZodTypeAny, {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        }, {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        }>>;
        violence: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
            filtered: z.ZodBoolean;
        }, {
            severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
        }>, "strip", z.ZodTypeAny, {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        }, {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        }>>;
        hate: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
            filtered: z.ZodBoolean;
        }, {
            severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
        }>, "strip", z.ZodTypeAny, {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        }, {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        }>>;
        self_harm: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
            filtered: z.ZodBoolean;
        }, {
            severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
        }>, "strip", z.ZodTypeAny, {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        }, {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        }>>;
        profanity: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
            filtered: z.ZodBoolean;
        }, {
            detected: z.ZodBoolean;
        }>, "strip", z.ZodTypeAny, {
            filtered: boolean;
            detected: boolean;
        }, {
            filtered: boolean;
            detected: boolean;
        }>>;
        error: z.ZodOptional<z.ZodObject<{
            code: z.ZodOptional<z.ZodString>;
            message: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            code?: string | undefined;
            message?: string | undefined;
        }, {
            code?: string | undefined;
            message?: string | undefined;
        }>>;
    }, {
        jailbreak: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
            filtered: z.ZodBoolean;
        }, {
            detected: z.ZodBoolean;
        }>, "strip", z.ZodTypeAny, {
            filtered: boolean;
            detected: boolean;
        }, {
            filtered: boolean;
            detected: boolean;
        }>>;
    }>, "strip", z.ZodTypeAny, {
        jailbreak?: {
            filtered: boolean;
            detected: boolean;
        } | undefined;
        sexual?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        violence?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        hate?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        self_harm?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        profanity?: {
            filtered: boolean;
            detected: boolean;
        } | undefined;
        error?: {
            code?: string | undefined;
            message?: string | undefined;
        } | undefined;
    }, {
        jailbreak?: {
            filtered: boolean;
            detected: boolean;
        } | undefined;
        sexual?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        violence?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        hate?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        self_harm?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        profanity?: {
            filtered: boolean;
            detected: boolean;
        } | undefined;
        error?: {
            code?: string | undefined;
            message?: string | undefined;
        } | undefined;
    }>>;
}, {
    message: z.ZodObject<{
        role: z.ZodLiteral<"assistant">;
        name: z.ZodOptional<z.ZodString>;
        content: z.ZodOptional<z.ZodString>;
        function_call: z.ZodOptional<z.ZodObject<{
            name: z.ZodString;
            arguments: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            name: string;
            arguments: string;
        }, {
            name: string;
            arguments: string;
        }>>;
        tool_calls: z.ZodOptional<z.ZodArray<z.ZodObject<{
            id: z.ZodString;
            type: z.ZodLiteral<"function">;
            function: z.ZodObject<{
                name: z.ZodString;
                arguments: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                name: string;
                arguments: string;
            }, {
                name: string;
                arguments: string;
            }>;
        }, "strip", z.ZodTypeAny, {
            function: {
                name: string;
                arguments: string;
            };
            type: "function";
            id: string;
        }, {
            function: {
                name: string;
                arguments: string;
            };
            type: "function";
            id: string;
        }>, "many">>;
    }, "strip", z.ZodTypeAny, {
        role: "assistant";
        name?: string | undefined;
        content?: string | undefined;
        function_call?: {
            name: string;
            arguments: string;
        } | undefined;
        tool_calls?: {
            function: {
                name: string;
                arguments: string;
            };
            type: "function";
            id: string;
        }[] | undefined;
    }, {
        role: "assistant";
        name?: string | undefined;
        content?: string | undefined;
        function_call?: {
            name: string;
            arguments: string;
        } | undefined;
        tool_calls?: {
            function: {
                name: string;
                arguments: string;
            };
            type: "function";
            id: string;
        }[] | undefined;
    }>;
}>, "strip", z.ZodTypeAny, {
    message: {
        role: "assistant";
        name?: string | undefined;
        content?: string | undefined;
        function_call?: {
            name: string;
            arguments: string;
        } | undefined;
        tool_calls?: {
            function: {
                name: string;
                arguments: string;
            };
            type: "function";
            id: string;
        }[] | undefined;
    };
    index: number;
    content_filter_results?: {
        jailbreak?: {
            filtered: boolean;
            detected: boolean;
        } | undefined;
        sexual?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        violence?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        hate?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        self_harm?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        profanity?: {
            filtered: boolean;
            detected: boolean;
        } | undefined;
        error?: {
            code?: string | undefined;
            message?: string | undefined;
        } | undefined;
    } | undefined;
    finish_reason?: string | undefined;
}, {
    message: {
        role: "assistant";
        name?: string | undefined;
        content?: string | undefined;
        function_call?: {
            name: string;
            arguments: string;
        } | undefined;
        tool_calls?: {
            function: {
                name: string;
                arguments: string;
            };
            type: "function";
            id: string;
        }[] | undefined;
    };
    index: number;
    content_filter_results?: {
        jailbreak?: {
            filtered: boolean;
            detected: boolean;
        } | undefined;
        sexual?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        violence?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        hate?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        self_harm?: {
            filtered: boolean;
            severity: "low" | "high" | "safe" | "medium";
        } | undefined;
        profanity?: {
            filtered: boolean;
            detected: boolean;
        } | undefined;
        error?: {
            code?: string | undefined;
            message?: string | undefined;
        } | undefined;
    } | undefined;
    finish_reason?: string | undefined;
}>;
/**
 * @internal
 */
export declare const azureOpenAiChatCompletionOutputSchema: z.ZodObject<z.objectUtil.extendShape<{
    created: z.ZodNumber;
    id: z.ZodString;
    model: z.ZodString;
    object: z.ZodUnion<[z.ZodLiteral<"chat.completion">, z.ZodLiteral<"text_completion">]>;
    usage: z.ZodObject<{
        completion_tokens: z.ZodNumber;
        prompt_tokens: z.ZodNumber;
        total_tokens: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        completion_tokens: number;
        prompt_tokens: number;
        total_tokens: number;
    }, {
        completion_tokens: number;
        prompt_tokens: number;
        total_tokens: number;
    }>;
    prompt_filter_results: z.ZodOptional<z.ZodArray<z.ZodObject<{
        prompt_index: z.ZodOptional<z.ZodNumber>;
        content_filter_results: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
            sexual: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                filtered: z.ZodBoolean;
            }, {
                severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
            }>, "strip", z.ZodTypeAny, {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            }, {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            }>>;
            violence: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                filtered: z.ZodBoolean;
            }, {
                severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
            }>, "strip", z.ZodTypeAny, {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            }, {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            }>>;
            hate: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                filtered: z.ZodBoolean;
            }, {
                severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
            }>, "strip", z.ZodTypeAny, {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            }, {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            }>>;
            self_harm: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                filtered: z.ZodBoolean;
            }, {
                severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
            }>, "strip", z.ZodTypeAny, {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            }, {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            }>>;
            profanity: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                filtered: z.ZodBoolean;
            }, {
                detected: z.ZodBoolean;
            }>, "strip", z.ZodTypeAny, {
                filtered: boolean;
                detected: boolean;
            }, {
                filtered: boolean;
                detected: boolean;
            }>>;
            error: z.ZodOptional<z.ZodObject<{
                code: z.ZodOptional<z.ZodString>;
                message: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                code?: string | undefined;
                message?: string | undefined;
            }, {
                code?: string | undefined;
                message?: string | undefined;
            }>>;
        }, {
            jailbreak: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                filtered: z.ZodBoolean;
            }, {
                detected: z.ZodBoolean;
            }>, "strip", z.ZodTypeAny, {
                filtered: boolean;
                detected: boolean;
            }, {
                filtered: boolean;
                detected: boolean;
            }>>;
        }>, "strip", z.ZodTypeAny, {
            jailbreak?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            sexual?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            violence?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            hate?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            self_harm?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            profanity?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            error?: {
                code?: string | undefined;
                message?: string | undefined;
            } | undefined;
        }, {
            jailbreak?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            sexual?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            violence?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            hate?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            self_harm?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            profanity?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            error?: {
                code?: string | undefined;
                message?: string | undefined;
            } | undefined;
        }>>;
    }, "strip", z.ZodTypeAny, {
        prompt_index?: number | undefined;
        content_filter_results?: {
            jailbreak?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            sexual?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            violence?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            hate?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            self_harm?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            profanity?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            error?: {
                code?: string | undefined;
                message?: string | undefined;
            } | undefined;
        } | undefined;
    }, {
        prompt_index?: number | undefined;
        content_filter_results?: {
            jailbreak?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            sexual?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            violence?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            hate?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            self_harm?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            profanity?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            error?: {
                code?: string | undefined;
                message?: string | undefined;
            } | undefined;
        } | undefined;
    }>, "many">>;
}, {
    choices: z.ZodArray<z.ZodObject<z.objectUtil.extendShape<{
        finish_reason: z.ZodOptional<z.ZodString>;
        index: z.ZodNumber;
        content_filter_results: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
            sexual: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                filtered: z.ZodBoolean;
            }, {
                severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
            }>, "strip", z.ZodTypeAny, {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            }, {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            }>>;
            violence: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                filtered: z.ZodBoolean;
            }, {
                severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
            }>, "strip", z.ZodTypeAny, {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            }, {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            }>>;
            hate: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                filtered: z.ZodBoolean;
            }, {
                severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
            }>, "strip", z.ZodTypeAny, {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            }, {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            }>>;
            self_harm: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                filtered: z.ZodBoolean;
            }, {
                severity: z.ZodUnion<[z.ZodLiteral<"safe">, z.ZodLiteral<"low">, z.ZodLiteral<"medium">, z.ZodLiteral<"high">]>;
            }>, "strip", z.ZodTypeAny, {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            }, {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            }>>;
            profanity: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                filtered: z.ZodBoolean;
            }, {
                detected: z.ZodBoolean;
            }>, "strip", z.ZodTypeAny, {
                filtered: boolean;
                detected: boolean;
            }, {
                filtered: boolean;
                detected: boolean;
            }>>;
            error: z.ZodOptional<z.ZodObject<{
                code: z.ZodOptional<z.ZodString>;
                message: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                code?: string | undefined;
                message?: string | undefined;
            }, {
                code?: string | undefined;
                message?: string | undefined;
            }>>;
        }, {
            jailbreak: z.ZodOptional<z.ZodObject<z.objectUtil.extendShape<{
                filtered: z.ZodBoolean;
            }, {
                detected: z.ZodBoolean;
            }>, "strip", z.ZodTypeAny, {
                filtered: boolean;
                detected: boolean;
            }, {
                filtered: boolean;
                detected: boolean;
            }>>;
        }>, "strip", z.ZodTypeAny, {
            jailbreak?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            sexual?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            violence?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            hate?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            self_harm?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            profanity?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            error?: {
                code?: string | undefined;
                message?: string | undefined;
            } | undefined;
        }, {
            jailbreak?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            sexual?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            violence?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            hate?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            self_harm?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            profanity?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            error?: {
                code?: string | undefined;
                message?: string | undefined;
            } | undefined;
        }>>;
    }, {
        message: z.ZodObject<{
            role: z.ZodLiteral<"assistant">;
            name: z.ZodOptional<z.ZodString>;
            content: z.ZodOptional<z.ZodString>;
            function_call: z.ZodOptional<z.ZodObject<{
                name: z.ZodString;
                arguments: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                name: string;
                arguments: string;
            }, {
                name: string;
                arguments: string;
            }>>;
            tool_calls: z.ZodOptional<z.ZodArray<z.ZodObject<{
                id: z.ZodString;
                type: z.ZodLiteral<"function">;
                function: z.ZodObject<{
                    name: z.ZodString;
                    arguments: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    name: string;
                    arguments: string;
                }, {
                    name: string;
                    arguments: string;
                }>;
            }, "strip", z.ZodTypeAny, {
                function: {
                    name: string;
                    arguments: string;
                };
                type: "function";
                id: string;
            }, {
                function: {
                    name: string;
                    arguments: string;
                };
                type: "function";
                id: string;
            }>, "many">>;
        }, "strip", z.ZodTypeAny, {
            role: "assistant";
            name?: string | undefined;
            content?: string | undefined;
            function_call?: {
                name: string;
                arguments: string;
            } | undefined;
            tool_calls?: {
                function: {
                    name: string;
                    arguments: string;
                };
                type: "function";
                id: string;
            }[] | undefined;
        }, {
            role: "assistant";
            name?: string | undefined;
            content?: string | undefined;
            function_call?: {
                name: string;
                arguments: string;
            } | undefined;
            tool_calls?: {
                function: {
                    name: string;
                    arguments: string;
                };
                type: "function";
                id: string;
            }[] | undefined;
        }>;
    }>, "strip", z.ZodTypeAny, {
        message: {
            role: "assistant";
            name?: string | undefined;
            content?: string | undefined;
            function_call?: {
                name: string;
                arguments: string;
            } | undefined;
            tool_calls?: {
                function: {
                    name: string;
                    arguments: string;
                };
                type: "function";
                id: string;
            }[] | undefined;
        };
        index: number;
        content_filter_results?: {
            jailbreak?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            sexual?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            violence?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            hate?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            self_harm?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            profanity?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            error?: {
                code?: string | undefined;
                message?: string | undefined;
            } | undefined;
        } | undefined;
        finish_reason?: string | undefined;
    }, {
        message: {
            role: "assistant";
            name?: string | undefined;
            content?: string | undefined;
            function_call?: {
                name: string;
                arguments: string;
            } | undefined;
            tool_calls?: {
                function: {
                    name: string;
                    arguments: string;
                };
                type: "function";
                id: string;
            }[] | undefined;
        };
        index: number;
        content_filter_results?: {
            jailbreak?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            sexual?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            violence?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            hate?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            self_harm?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            profanity?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            error?: {
                code?: string | undefined;
                message?: string | undefined;
            } | undefined;
        } | undefined;
        finish_reason?: string | undefined;
    }>, "many">;
    system_fingerprint: z.ZodNullable<z.ZodString>;
}>, "strip", z.ZodTypeAny, {
    object: "chat.completion" | "text_completion";
    id: string;
    model: string;
    usage: {
        completion_tokens: number;
        prompt_tokens: number;
        total_tokens: number;
    };
    created: number;
    choices: {
        message: {
            role: "assistant";
            name?: string | undefined;
            content?: string | undefined;
            function_call?: {
                name: string;
                arguments: string;
            } | undefined;
            tool_calls?: {
                function: {
                    name: string;
                    arguments: string;
                };
                type: "function";
                id: string;
            }[] | undefined;
        };
        index: number;
        content_filter_results?: {
            jailbreak?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            sexual?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            violence?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            hate?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            self_harm?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            profanity?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            error?: {
                code?: string | undefined;
                message?: string | undefined;
            } | undefined;
        } | undefined;
        finish_reason?: string | undefined;
    }[];
    system_fingerprint: string | null;
    prompt_filter_results?: {
        prompt_index?: number | undefined;
        content_filter_results?: {
            jailbreak?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            sexual?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            violence?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            hate?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            self_harm?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            profanity?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            error?: {
                code?: string | undefined;
                message?: string | undefined;
            } | undefined;
        } | undefined;
    }[] | undefined;
}, {
    object: "chat.completion" | "text_completion";
    id: string;
    model: string;
    usage: {
        completion_tokens: number;
        prompt_tokens: number;
        total_tokens: number;
    };
    created: number;
    choices: {
        message: {
            role: "assistant";
            name?: string | undefined;
            content?: string | undefined;
            function_call?: {
                name: string;
                arguments: string;
            } | undefined;
            tool_calls?: {
                function: {
                    name: string;
                    arguments: string;
                };
                type: "function";
                id: string;
            }[] | undefined;
        };
        index: number;
        content_filter_results?: {
            jailbreak?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            sexual?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            violence?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            hate?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            self_harm?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            profanity?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            error?: {
                code?: string | undefined;
                message?: string | undefined;
            } | undefined;
        } | undefined;
        finish_reason?: string | undefined;
    }[];
    system_fingerprint: string | null;
    prompt_filter_results?: {
        prompt_index?: number | undefined;
        content_filter_results?: {
            jailbreak?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            sexual?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            violence?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            hate?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            self_harm?: {
                filtered: boolean;
                severity: "low" | "high" | "safe" | "medium";
            } | undefined;
            profanity?: {
                filtered: boolean;
                detected: boolean;
            } | undefined;
            error?: {
                code?: string | undefined;
                message?: string | undefined;
            } | undefined;
        } | undefined;
    }[] | undefined;
}>;
//# sourceMappingURL=azure-openai-types-schema.d.ts.map